import {provideHttpClient} from '@angular/common/http';
import {ApplicationConfig, provideZoneChangeDetection} from '@angular/core';
import {provideAnimationsAsync} from '@angular/platform-browser/animations/async';
import {provideRouter} from '@angular/router';
import {routes} from '@app/app.routes';
import {OpenAPI} from '@core/ems/core/OpenAPI';
import {LogLevel, provideAuth} from 'angular-auth-oidc-client';

OpenAPI.BASE = 'http://localhost:8080';

export const appConfig: ApplicationConfig = {
    providers: [
        provideZoneChangeDetection({eventCoalescing: true}),
        provideAnimationsAsync(),
        provideRouter(routes),
        provideHttpClient(),
        provideAuth({
            config: {
                authority: 'https://keycloak.szut.dev/auth/realms/szut',
                redirectUrl: window.location.origin,
                postLogoutRedirectUri: window.location.origin,
                clientId: 'employee-management-service',
                scope: 'openid profile email offline_access',
                responseType: 'code',
                silentRenew: true,
                useRefreshToken: true,
                logLevel: LogLevel.Error,
            },
        })
    ],
};
