import { Injectable } from '@angular/core';
import UserData from '@core/auth/UserData';
import { OidcSecurityService } from 'angular-auth-oidc-client';
import { Observable } from 'rxjs';

import { OpenAPI } from '../ems';

@Injectable({
    providedIn: 'root'
})
export class AuthService {
    public $user: Observable<UserData | undefined>;

    constructor(private readonly oidcSecurityService: OidcSecurityService) {
        this.$user = new Observable((publish) => {
            this.oidcSecurityService.checkAuth().subscribe(({ isAuthenticated, userData }) => {
                publish.next(isAuthenticated ? {
                    username: userData.preferred_username,
                    verified: userData.email_verified
                } : undefined);
            });
        });
        this.oidcSecurityService.getAccessToken().subscribe(token => OpenAPI.TOKEN = token);

    }

    login() {
        this.oidcSecurityService.authorize();
    }

    logout() {
        this.oidcSecurityService.logoff();
    }

}
