// This file is auto-generated by @hey-api/openapi-ts

import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import type { Observable } from 'rxjs';
import { OpenAPI } from './core/OpenAPI';
import { request as __request } from './core/request';
import type { GetAllQualificationsResponse, CreateQualificationData, CreateQualificationResponse, UpdateQualificationData, UpdateQualificationResponse, DeleteQualificationData, DeleteQualificationResponse, GetAllQualificationEmployeesData, GetAllQualificationEmployeesResponse, GetAllEmployeesResponse, CreateEmployeeData, CreateEmployeeResponse, GetEmployeeData, GetEmployeeResponse, DeleteEmployeeData, DeleteEmployeeResponse, UpdateEmployeeData, UpdateEmployeeResponse, GetAllEmployeeQualificationsData, GetAllEmployeeQualificationsResponse, AddQualificationToEmployeeData, AddQualificationToEmployeeResponse, RemoveQualificationFromEmployeeData, RemoveQualificationFromEmployeeResponse } from './types.gen';

@Injectable({
    providedIn: 'root'
})
export class QualificationService {
    constructor(public readonly http: HttpClient) { }
    
    /**
     * Get a list of all available qualifications
     * @returns Qualification list of qualifications
     * @throws ApiError
     */
    public getAllQualifications(): Observable<GetAllQualificationsResponse> {
        return __request(OpenAPI, this.http, {
            method: 'GET',
            url: '/qualifications',
            errors: {
                401: 'not authorized'
            }
        });
    }
    
    /**
     * Creates a new qualification
     * @param data The data for the request.
     * @param data.requestBody
     * @returns Qualification created qualification
     * @throws ApiError
     */
    public createQualification(data: CreateQualificationData): Observable<CreateQualificationResponse> {
        return __request(OpenAPI, this.http, {
            method: 'POST',
            url: '/qualifications',
            body: data.requestBody,
            mediaType: 'application/json',
            errors: {
                400: 'invalid JSON posted',
                401: 'not authorized'
            }
        });
    }
    
    /**
     * Updates a qualification
     * @param data The data for the request.
     * @param data.id
     * @param data.requestBody
     * @returns Qualification updated qualification
     * @throws ApiError
     */
    public updateQualification(data: UpdateQualificationData): Observable<UpdateQualificationResponse> {
        return __request(OpenAPI, this.http, {
            method: 'PUT',
            url: '/qualifications/{id}',
            path: {
                id: data.id
            },
            body: data.requestBody,
            mediaType: 'application/json',
            errors: {
                400: 'invalid JSON posted',
                401: 'not authorized',
                404: 'resource not found'
            }
        });
    }
    
    /**
     * Deletes a qualification
     * @param data The data for the request.
     * @param data.id
     * @returns void delete successful
     * @throws ApiError
     */
    public deleteQualification(data: DeleteQualificationData): Observable<DeleteQualificationResponse> {
        return __request(OpenAPI, this.http, {
            method: 'DELETE',
            url: '/qualifications/{id}',
            path: {
                id: data.id
            },
            errors: {
                401: 'not authorized',
                403: 'qualification is in use',
                404: 'resource not found'
            }
        });
    }
    
    /**
     * Get all employees with a specific qualification
     * @param data The data for the request.
     * @param data.id
     * @returns QualificationEmployees List of employees who have the desired qualification
     * @throws ApiError
     */
    public getAllQualificationEmployees(data: GetAllQualificationEmployeesData): Observable<GetAllQualificationEmployeesResponse> {
        return __request(OpenAPI, this.http, {
            method: 'GET',
            url: '/qualifications/{id}/employees',
            path: {
                id: data.id
            },
            errors: {
                401: 'not authorized',
                404: 'qualification id does not exist'
            }
        });
    }
    
}

@Injectable({
    providedIn: 'root'
})
export class EmployeeService {
    constructor(public readonly http: HttpClient) { }
    
    /**
     * Get a list of all available employees
     * @returns Employee list of employees
     * @throws ApiError
     */
    public getAllEmployees(): Observable<GetAllEmployeesResponse> {
        return __request(OpenAPI, this.http, {
            method: 'GET',
            url: '/employees',
            errors: {
                401: 'not authorized'
            }
        });
    }
    
    /**
     * Creates a new employee
     * @param data The data for the request.
     * @param data.requestBody
     * @returns Employee created employee
     * @throws ApiError
     */
    public createEmployee(data: CreateEmployeeData): Observable<CreateEmployeeResponse> {
        return __request(OpenAPI, this.http, {
            method: 'POST',
            url: '/employees',
            body: data.requestBody,
            mediaType: 'application/json',
            errors: {
                400: 'invalid JSON posted',
                401: 'not authorized'
            }
        });
    }
    
    /**
     * Gets a specific employee
     * @param data The data for the request.
     * @param data.id
     * @returns Employee employee
     * @throws ApiError
     */
    public getEmployee(data: GetEmployeeData): Observable<GetEmployeeResponse> {
        return __request(OpenAPI, this.http, {
            method: 'GET',
            url: '/employees/{id}',
            path: {
                id: data.id
            },
            errors: {
                401: 'not authorized',
                404: 'resource not found'
            }
        });
    }
    
    /**
     * Deletes a specific employee
     * @param data The data for the request.
     * @param data.id
     * @returns void delete successful
     * @throws ApiError
     */
    public deleteEmployee(data: DeleteEmployeeData): Observable<DeleteEmployeeResponse> {
        return __request(OpenAPI, this.http, {
            method: 'DELETE',
            url: '/employees/{id}',
            path: {
                id: data.id
            },
            errors: {
                401: 'not authorized',
                404: 'resource not found'
            }
        });
    }
    
    /**
     * Updates a employee
     * @param data The data for the request.
     * @param data.id
     * @param data.requestBody
     * @returns Employee employee
     * @throws ApiError
     */
    public updateEmployee(data: UpdateEmployeeData): Observable<UpdateEmployeeResponse> {
        return __request(OpenAPI, this.http, {
            method: 'PATCH',
            url: '/employees/{id}',
            path: {
                id: data.id
            },
            body: data.requestBody,
            mediaType: 'application/json',
            errors: {
                401: 'not authorized',
                404: 'resource not found'
            }
        });
    }
    
    /**
     * Gets all qualifications of a specific employee
     * @param data The data for the request.
     * @param data.id
     * @returns EmployeeQualifications employee with a list of his qualifications
     * @throws ApiError
     */
    public getAllEmployeeQualifications(data: GetAllEmployeeQualificationsData): Observable<GetAllEmployeeQualificationsResponse> {
        return __request(OpenAPI, this.http, {
            method: 'GET',
            url: '/employees/{id}/qualifications',
            path: {
                id: data.id
            },
            errors: {
                401: 'not authorized',
                404: 'resource not found'
            }
        });
    }
    
    /**
     * Adds a qualification to an employee
     * @param data The data for the request.
     * @param data.id
     * @param data.requestBody
     * @returns EmployeeQualifications employee with a list of his qualifications
     * @throws ApiError
     */
    public addQualificationToEmployee(data: AddQualificationToEmployeeData): Observable<AddQualificationToEmployeeResponse> {
        return __request(OpenAPI, this.http, {
            method: 'POST',
            url: '/employees/{id}/qualifications',
            path: {
                id: data.id
            },
            body: data.requestBody,
            mediaType: 'application/json',
            errors: {
                400: 'invalid JSON posted or employee already has this qualification',
                401: 'not authorized',
                404: 'resource not found'
            }
        });
    }
    
    /**
     * Removes a qualification from an employee
     * @param data The data for the request.
     * @param data.employeeId
     * @param data.qualificationId
     * @returns EmployeeQualifications employee with a list of his qualifications
     * @throws ApiError
     */
    public removeQualificationFromEmployee(data: RemoveQualificationFromEmployeeData): Observable<RemoveQualificationFromEmployeeResponse> {
        return __request(OpenAPI, this.http, {
            method: 'DELETE',
            url: '/employees/{employeeId}/qualifications/{qualificationId}',
            path: {
                employeeId: data.employeeId,
                qualificationId: data.qualificationId
            },
            errors: {
                401: 'not authorized',
                404: 'resource not found'
            }
        });
    }
    
}